==> kube-integration-1.2.6.tgz: package/lib/helm/release/tests/release.controller.unit.spec.js <==
'use strict';

const chai = require('chai');
const sinonChai = require('sinon-chai');
const _ = require('lodash');
const proxyquire = require('proxyquire');
const Promise = require('bluebird');
const expect = chai.expect;

chai.use(sinonChai);

class FakeRelease {
    constructor(data) {
        this._name = data['NAME'];
        this._history = [];
    }

    finalize() {}

    initRevisionData() {
        return Promise.resolve('');
    }
};

class FakeConfigMap {

    getMetadata() {
        return {};
    }
    getLabels() {
        return {
            'NAME': Math.random()
        };
    }
    getProperty() {
        return {};
    }
};

function getFakeController() {
    return {
        describe() {
            return Promise.resolve({});
        },
        get() {
            return Promise.resolve([
                new FakeConfigMap({
                    name: 'r1'
                }), new FakeConfigMap({
                    name: 'r2'
                })
            ]);
        }
    };
}

function getFakeConstructorOptions() {
    return {
        kubeManager: {
            getServiceController: getFakeController,
            getConfigmapController: getFakeController,
            getPodController: getFakeController
        }
    };
}

describe('helm release controller', () => {
    describe('get:', () => {
        it('should get all releases', () => {
            const CtrlPrxy = proxyquire('./../release.controller', {
                './release': FakeRelease
            });

            const ctrl = new CtrlPrxy(getFakeConstructorOptions());
            return ctrl.get()
                .then((releases) => {
                    console.log(`${releases}`);
                    expect(releases.length).to.be.equal(2);
                });
        });
    });

    describe('Tiller version', () => {
        it('Should get', () => {
            const CtrlPrxy = proxyquire('./../release.controller', {
                './release': FakeRelease
            });
            const ctrl = new CtrlPrxy({
                kubeManager: {
                    getServiceController: () => {
                        return {
                            describe() {
                                return Promise.resolve({
                                    getServiceSelector: () => {
                                        return {
                                            app: 'helm',
                                            name: 'tiller'
                                        }
                                    }
                                });
                            }
                        }
                    },
                    getPodController: () => {
                        return {
                            get(filter) {
                                return [{
                                    getImages(){
                                        return [
                                            {
                                                name: 'gcr.io/kubernetes-helm/tiller:v2.5.1'
                                            }
                                        ]
                                    }
                                }];
                            }
                        };
                    }
                }
            });
            return ctrl.getTillerVersion()
                .then((version) => {
                    expect(version).to.be.deep.equal('v2.5.1');
                });
        });
    });
});

==> kube-integration-1.2.11.tgz: package/lib/helm/release/tests/release.controller.unit.spec.js <==
'use strict';

const chai = require('chai');
const sinonChai = require('sinon-chai');
const _ = require('lodash');
const proxyquire = require('proxyquire');
const Promise = require('bluebird');
const expect = chai.expect;

chai.use(sinonChai);

class FakeRelease {
    constructor(data){
        this._name = data['NAME'];
        this._history = [];
    }

    finalize(){}
};

class FakeConfigMap {

    getMetadata(){
        return {};
    }
    getLabels(){
        return {
            'NAME': Math.random()            
        };
    }
    getProperty(){
        return {};
    }
};

function getFakeController(){
    return { 
        describe(){
            return Promise.resolve({});
        },
        get() {
            return Promise.resolve([
                new FakeConfigMap({
                    name: 'r1'
                }), new FakeConfigMap({
                    name: 'r2'
                })
            ]);
        }
    };
}

function getFakeConstructorOptions(){
    return {
        kubeManager: {
            getServiceController: getFakeController,
            getConfigmapController: getFakeController
        }
    };
}

describe('helm release controller', () => {
    describe('get:', () => {
        it('should get all releases', () => {
            const CtrlPrxy = proxyquire('./../release.controller', {
                './release': FakeRelease
            });

            const ctrl = new CtrlPrxy(getFakeConstructorOptions());
            return ctrl.get()
            .then((releases) => {
                console.log(`${releases}`);
                expect(releases.length).to.be.equal(2);
            });
        });

        it('Should throw an error when tiller not found on the namespace', () => {
            const CtrlPrxy = proxyquire('./../release.controller', {});
            const ctrl = new CtrlPrxy({
                kubeManager: {
                    getServiceController: () => {
                        return {
                            describe(){
                                return Promise.reject(new Error('Error will not be at the final'));
                            }
                        }
                    }
                },
                ns: 'namespace-without-tiller'
            });

            return ctrl.get()
            .catch((err) => {
                expect(err.message).to.be.deep.equal('Tiller not found in namespace namespace-without-tiller');    
                return;
            });
        });
    });
});
